import json
from pathlib import Path
import epdx
from shared import get_epds, get_full_epd, get_folder, get_compliance_id


def download_to_epdx(data_folder: Path, search_key: str, limit: int = 50):
    """Download 50 EPDs and save them locally as EPDx files"""

    data = get_epds(
        {"name": search_key, "compliance": get_compliance_id("a1")},
        limit=limit
    )
    print(f"Downloading {limit} EPDs\n")

    for _epd in data.get("data"):
        epd_id = _epd.get("uuid")
        epdx_file_path = data_folder / f"{epd_id}.epdx.json"

        if not epdx_file_path.exists():
            print(f"Downloading EPD: {epd_id[:8]} to {'/'.join(data_folder.parts[-3:])}")

            # Get Full EPD from Ökobau
            epd = get_full_epd(epd_id)

            # Convert to EPDx
            try:
                epdx_data = epdx.convert_ilcd(epd, as_type=str)
                epdx_file_path.write_text(epdx_data)
            except epdx.ParsingException:
                print(f"Error in ID: {epd_id}")
                (data_folder / f"{epd_id}.json").write_text(json.dumps(epd, indent=2))
        else:
            print(f"EPD: {epd_id[:8]} already in {'/'.join(data_folder.parts[-3:])}")


if __name__ == "__main__":
    _folder = get_folder(__file__, "data")

    download_to_epdx(_folder, "beton")
