from pathlib import Path

import requests

OKOBAU_URL = "https://oekobaudat.de/OEKOBAU.DAT/resource/datastocks/cd2bda71-760b-4fcc-8a0b-3877c10000a8"


def get_folder(source, name: str) -> Path:
    """Get or create a folder with the given name"""

    folder = Path(source).parent / name
    if not folder.exists():
        folder.mkdir()

    return folder


def get_compliance_id(value: str) -> str:
    compliance_values = {
        "a1": "b00f9ec0-7874-11e3-981f-0800200c9a66",
        "a2": "c0016b33-8cf7-415c-ac6e-deba0d21440d",
    }

    return compliance_values.get(value.lower())


def get_epds(search: dict[str, str] | None, limit=10) -> dict:
    """Get EPDs from Ökobau"""

    response = requests.get(
        f"{OKOBAU_URL}/processes?"
        f"format=json"
        f"&pageSize={limit}"
        f"{'&search=true&' + '&'.join([f'{key}={value}' for key, value in search.items()]) if search else ''}"
    )
    response.raise_for_status()
    data = response.json()

    print(
        f"Retrieved {data.get('pageSize')} EPDs out of {data.get('totalCount')} from Ökobau"
    )

    return data


def get_full_epd(uid: str) -> dict:
    """Get the full dataset for a single EPD"""

    base_url = f"{OKOBAU_URL}/processes/{uid}"
    response = requests.get(f"{base_url}?format=json&view=extended")

    response.raise_for_status()
    data: dict = response.json()
    data["source"] = base_url

    return data
